@@ -608,6 +608,10 @@ def dotProd(ms2A, ms2B, mzTol=0.02, rep='simple'):
         The second MS2.
     mzTol: float
         Tolerance of the m/z difference.
+    rep: str
+        Representation of the MS2 spectrum. 'simple' for only
+        reporting the dot product. 'full' for reporting the
+        dot product and number of matched peaks.
     """
 
     # Check if MS2 exist in both spectra
@@ -650,7 +654,7 @@ def dotProd(ms2A, ms2B, mzTol=0.02, rep='simple'):
     if rep == 'simple':
         return dp
     elif rep == 'full':
-        return {'dotprod': dp, 'matchNumber': len(matchNum)}
+        return {'dotprod': dp, 'matchNumber': matchNum}
 
 
 def numberUniqueMS2(d, rtTol=1.0, precsMzTol=0.01, dpTol=0.95):
